#
# spec file for package psgml
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           psgml
BuildRequires:  emacs-nox
%if 0%{?suse_version} > 1220
BuildRequires:  makeinfo
%endif
BuildRequires:  unzip
%define tdtd tdtd.zip
Requires:       emacs_program
Summary:        Emacs Add-On to edit SGML/XML documents
License:        GPL-2.0+ and SUSE-Public-Domain
Group:          Productivity/Editors/Emacs
Version:        1.4.1
Release:        bp153.1.12
Source:         https://marmalade-repo.org/packages/psgml-%{version}.tar
Source1:        http://home.sprynet.com/sprynet/dmeggins/psgml-dsssl.el
Source2:        http://logimac.mathematik.uni-freiburg.de/mixed/psgml-ja.tgz
Source3:        http://www.menteith.com/tdtd/data/tdtd.zip
Source4:        http://www.iro.umontreal.ca/~pinard/xxml/xxml.tar.gz
Source5:        http://www.megginson.com/Software/psgml-xpointer.el
Source6:        %{name}-README.openSUSE
Source7:        ke-docbook.el
Source8:        suse-start-psgml.el
Source9:        psgml-html.el
Patch:          psgml-compile-addons.diff
Patch2:         psgml-1.2.5-key.diff
Patch3:         psgml-xpointer.el.diff
Patch4:         psgml-1.3.1-texi-category.diff
Patch5:         psgml-xxml-namespace-face.diff
Patch6:         tdtd-dtd-patch
Patch7:         xxml-indentation.diff
Patch8:         flavour.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Url:            http://sourceforge.net/projects/psgml/
PreReq:         %install_info_prereq

%description
'psgml' supports you while editing SGML/XML documents.	It respects the
context of the used DTD (Document Type Definition) and offers the valid
elements and attributes.

Included are several helper tools: tdtd, xxml, psgml-xpointer.

For more info see README.openSUSE.

Compiled for GNU Emacs (XEmacs has its own version!).



Authors:
--------
    James Clark <jjc@clark.com>
    Lennart Staflin <lenst@lysator.liu.se>
    David Megginson <dmeggins@sprynet.com>
    Matthias Clasen <mclasen@sun2.mathematik.uni-freiburg.de>
    François Pinard <pinard@iro.umontreal.ca>
    etc.

%prep
%setup -q
%patch -p1
cp -p %{SOURCE1} .
# xxml
mkdir xxml
tar vxz -C xxml -f %{SOURCE4}
%patch -P 5 -p0
%patch7 -p1
cp xxml/xxml.el .
for f in README THANKS; do
  cp xxml/$f $f.xxml
done
cp -p %{SOURCE5} .
%patch -P 2 -p1 -P 3 -p1 -P 4 -p1
%setup -q -T -D -a 2
mv psgml-jade/psgml-jade.el .
unzip -o -a %{SOURCE3}
# Add write permissions so that we can patch it
chmod u+w tutorial.txt
cp -p %{SOURCE6} README.openSUSE
cp -p %{SOURCE7} .
cp -p %{SOURCE8} .
cp -p %{S:9} .
%patch -p 1 -P 6
%patch8

%build
./configure --prefix=%{_prefix} --infodir=%{_infodir}
make # emacs
echo "(add-to-list (quote load-path) (getenv \"PWD\"))" > load-psgml.el
emacs --batch --no-site -l load-psgml.el \
      -l ./tdtd-font.el \
      -f batch-byte-compile tdtd-font.el tdtd-font-maker.el tdtd.el
emacs --batch --no-site -l load-psgml.el -f batch-byte-compile xxml.el
emacs --batch --no-site -l load-psgml.el -l ./xxml.el \
      -f batch-byte-compile ke-docbook.el
emacs --batch --no-site -l load-psgml.el -f batch-byte-compile psgml-xpointer.el
emacs --batch --no-site -l load-psgml.el -l tempo -f batch-byte-compile psgml-html.el
makeinfo psgml.texi
makeinfo psgml-api.texi

%install
[ -z $RPM_BUILD_ROOT ] || rm -fr $RPM_BUILD_ROOT
install -d -m755 $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml \
                 $RPM_BUILD_ROOT%{_infodir}
# to avoid timestamp problems, install .el files first.
install -p -m644 *.el $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml
rm -f $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/suse-start*
make install prefix="$RPM_BUILD_ROOT%{_prefix}" \
             lispdir="$RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml" \
             infodir="$RPM_BUILD_ROOT%{_infodir}"
make install-info prefix="$RPM_BUILD_ROOT%{_prefix}" \
                  lispdir="$RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml" \
                  infodir="$RPM_BUILD_ROOT%{_infodir}"
#install -p -m644 suse-start-psgml.el \
#    $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/suse-start-psgml.el
install -p -m644 iso88591.map \
    $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/iso88591.map
install -p -m644 tdtd-font.el tdtd-font.elc \
                 tdtd-font-maker.el tdtd-font-maker.elc \
                 tdtd.el tdtd.elc \
                 $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/
install -p -m644 xxml.el xxml.elc \
    $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/
install -p -m644 ke-docbook.el ke-docbook.elc \
    $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/
install -p -m644 psgml-xpointer.el psgml-xpointer.elc \
    $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/psgml/
pushd $RPM_BUILD_ROOT%{_infodir}/
  gzip -9f psgml-api.info psgml.info
popd
ln -f tutorial.txt tdtd-tutorial.txt
ln -f readme.txt tdtd-readme.txt
ln -f dot_emacs tdtd.dot.emacs

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/psgml-api.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/psgml-api.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.psgml README.openSUSE
%doc README.xxml THANKS.xxml
%doc suse-start-psgml.el
%doc psgml-jade
%doc tdtd-readme.txt tdtd-tutorial.txt tdtd.dot.emacs
# %config %{_prefix}/share/emacs/site-lisp/suse-start-psgml.el
%{_prefix}/share/emacs/site-lisp/psgml
%doc %{_infodir}/psgml-api.info*
%doc %{_infodir}/psgml.info*

%changelog
* Mon Feb 19 2018 ke@suse.com
- Stop loading psgml automatically because of conflicts with js-mode.el;
  bsc#1080086.
* Mon Dec 15 2014 ke@suse.de
- Update from https://marmalade-repo.org/packages/psgml-1.4.1.tar;
  bnc#909627.
- Cleanup spec file.
* Sat Sep 15 2012 idonmez@suse.com
- Add BuildRequires on makeinfo to fix Factory build
* Mon Jul  2 2012 werner@suse.de
- Add fix for new emacs 24.1, compare with
  https://lists.gnu.org/archive/html/emacs-devel/2011-12/msg00259.html
* Sun May  9 2010 aj@suse.de
- Fix build with new patch.
* Wed Dec  2 2009 coolo@novell.com
- update patches to fix build
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Mar 29 2007 rguenther@suse.de
- add unzip BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jul 26 2005 ke@suse.de
- Require 'emacs_program'.
* Wed Mar  9 2005 ke@suse.de
- Update to version 1.3.2:
  * Bugfixes
  * Better ID support.
  * Move all menus to one SGML menu.
- psgml-id.dif: Remove it (obsolete).
* Mon Mar  7 2005 ke@suse.de
- Do not let xxml override sgml-indent-data; reported by Ulrich Windl
  [# 71065].
* Thu Jul  1 2004 ke@suse.de
- Fix reported typo in .changes.
* Mon Feb  9 2004 ke@suse.de
- tdtd-dtd-patch: Fix syntax of the DTD included in the tdtd manual;
  reported by Jochen Hayek.
- Use norootforbuild.
* Wed Jun 18 2003 ke@suse.de
- psgml-xxml-namespace-face.diff: Allow ';' and '.' in element name;
  thus face lock can recognize namespace prefixes.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb  7 2003 ke@suse.de
- Use install_info macro [# 23451].
- psgml-1.3.1-texi-category.diff: Use proper Info categories.
* Tue Jan  7 2003 ke@suse.de
- Update to version 1.3.1:
  * XML related enhancements (DTD-less editing),
  * Mule related fixes.
  * Default to font-lock if available.
* Wed Dec 11 2002 ke@suse.de
- psgml-1.2.5-key.diff: De-assign keybinding C-c C-c from the
  command sgml-show-context to avoid clash with stock sgml-mode;
  reported by Martin Vidner [# 18039].
- Add psgml-html.el but don't activate it for now.
- Try to use text properties instead of overlays.
- suse-start-psgml.el: Loading xxml.el depends on suse-psgml-use-xxml.
* Wed Dec  4 2002 ke@suse.de
- Replace sp/jade (jade_dsl) references with opensp/openjade.
- Supply setting for XML validation.
* Tue Dec  3 2002 ke@suse.de
- Update the add-on xxml.el; cf. documentation in README.xxml once
  installed.  The name of some faces changed; adjust your settings in
  case of unexpected results.
* Mon Aug 12 2002 ke@suse.de
- Update to version 1.2.5:
  * Fix multibyte handling
  * Improve XML support.
- Drop superfluous mule patch.
- Rearrange patches.
* Mon Jul  8 2002 schwab@suse.de
- Remove global-font-lock-mode from startup file.
* Mon Nov 19 2001 ke@suse.de
- Update to version 1.2.3:
  . Compatible with Emacs 21 (thus drop psgml-emacs-21.diff).
  . Code cleanup.
- Cleanup spec file.
* Tue Nov 13 2001 ke@suse.de
- Use emacs-nox to build the package.
- Make the package 'noarch'.
* Thu Sep 13 2001 ke@suse.de
- Fix issues reported by Pavel JANIK (thanks) [#10504]:
  . Install tdtd-font-maker.elc.
  . suse-start-psgml.el: Init tdtd as recommended within the tdtd
    package.
  . suse-start-psgml.el: Don't set sgml-validate-command to the same
    value as done within psgml sources; add a comment how to use
    'onsgmls'.
* Mon Aug 27 2001 ke@suse.de
- Enhance sgml-public-map to make it recognize XML flavored ISO entity
  files.
- Rename README.SuSE to psgml-README.SuSE.
* Mon Jul 16 2001 ke@suse.de
- Update tdtd.zip (0.7.1).
- Apply 'xxml-provide.diff'.
- Add 'ke-docbook.el'; a start to fix [#9243].
- Instead of emacs.dot (was part of 'psgml-1.2.1.dif') use
  'suse-start-psgml.el' as a source file.
- Update README.SuSE.
- Fix dangling symlinks [#9391].
* Mon May 28 2001 ro@suse.de
- added README.SuSE as Source file.
* Fri May 25 2001 ke@suse.de
- Apply patch from emacs-21.0.104/etc/PROBLEMS.
- Start README.SuSE.
* Tue Mar 13 2001 ro@suse.de
- added emacs-x11 to neededforbuild.
* Thu Mar  8 2001 uli@suse.de
- added xf86 to neededforbuild
* Tue Feb 27 2001 ke@suse.de
- Update to version 1.2.2.
* Mon Dec 18 2000 ke@suse.de
- Fix a bug (Mule related) to make psgml work with ECAT files again;
  use a patch provided by ABE Yasushi
  (cf. http://www.geocrawler.com/lists/3/SourceForge/7085/0/4772957/).
- Move ./configure -> %%build.
* Fri Nov 17 2000 ro@suse.de
- ge_exec -> emacs
* Thu Oct 12 2000 ke@suse.de
- Fix typo in psgml-1.2.1.dif; now it compiles psgml-xpointer.el, too.
* Fri Sep 29 2000 ke@suse.de
- Add psgml-xpointer.el.
* Thu Jul 27 2000 ke@suse.de
- Add xxml.el.
* Mon Feb 28 2000 kukuk@suse.de
- Move /usr/info -> /usr/share/info
* Mon Jan 10 2000 ke@suse.de
- Update: version 1.2.1.
- Install /usr/share/emacs/site-lisp/suse-start-psgml.el.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Sep  9 1999 bs@suse.de
- fixed call of Check at the end of %%install section
* Thu Apr 15 1999 werner@suse.de
- Add export LC_CTYPE=ISO-8859-1 and export EMACS_UNIBYTE=1
  to build *and* install section
* Tue Nov 24 1998 ke@suse.de
- Update: psgml-1.1.6 (alpha!).
* Fri Oct 16 1998 ke@suse.de
- Update: psgml-1.1.4 (alpha!).
* Sun Aug  9 1998 ke@suse.de
- Update: psgml-1.1.3 (alpha!).
* Thu Aug  6 1998 ke@suse.de
- add the tdtd package.
* Mon Jul 27 1998 bs@suse.de
- added export LC_CTYPE=ISO-8859-1 to build section - emacs needs it.
* Fri Jul 10 1998 bs@suse.de
- added xaw3d to neededforbuild (ge_exec needs it)
* Sat Feb 28 1998 ke@suse.de
- update psgml-xml: psgmlxml-19980218.
* Mon Dec 15 1997 ke@suse.de
- add xml support: patch by David Megginson <dmeggins@sprynet.com>.
- add psgml-dsssl:  extension by David Megginson <dmeggins@sprynet.com>.
- add psgml-jade: extension by Matthias Clasen
  <mclasen@sun2.mathematik.uni-freiburg.de>.
* Thu Jun 26 1997 Karl Eichwalder  <ke@suse.de>
  * initial package: version 1.0.1
